@@ -1,14 +1,10 @@
-from __future__ import print_function, division, absolute_import
-
-from concurrent.futures import ThreadPoolExecutor
 import logging
 import socket
 
 from tornado import gen
 
 from .. import protocol
-from ..compatibility import finalize, PY3
-from ..utils import get_ip, get_ipv6, nbytes
+from ..utils import get_ip, get_ipv6, nbytes, offload
 
 
 logger = logging.getLogger(__name__)
@@ -19,18 +15,6 @@ logger = logging.getLogger(__name__)
 
 FRAME_OFFLOAD_THRESHOLD = 10 * 1024 ** 2  # 10 MB
 
-try:
-    _offload_executor = ThreadPoolExecutor(
-        max_workers=1, thread_name_prefix="Dask-Offload"
-    )
-except TypeError:
-    _offload_executor = ThreadPoolExecutor(max_workers=1)
-finalize(_offload_executor, _offload_executor.shutdown)
-
-
-def offload(fn, *args, **kwargs):
-    return _offload_executor.submit(fn, *args, **kwargs)
-
 
 @gen.coroutine
 def to_frames(msg, serializers=None, on_error="message", context=None):
@@ -50,10 +34,7 @@ def to_frames(msg, serializers=None, on_error="message", context=None):
             logger.exception(e)
             raise
 
-    if PY3:
-        res = yield offload(_to_frames)
-    else:  # distributed/deploy/tests/test_adaptive.py::test_get_scale_up_kwargs fails on Py27.  Don't know why
-        res = _to_frames()
+    res = yield offload(_to_frames)
 
     raise gen.Return(res)
 
