@@ -1,14 +1,12 @@
-from __future__ import print_function, division, absolute_import
-
 import atexit
 from datetime import timedelta
 import logging
 import os
+from queue import Queue as PyQueue
 import re
 import threading
 import weakref
 
-from .compatibility import finalize, Queue as PyQueue
 from .utils import mp_context
 
 from tornado import gen
@@ -112,7 +110,7 @@ class AsyncProcess(object):
             # We don't join the thread here as a finalizer can be called
             # asynchronously from anywhere
 
-        self._finalizer = finalize(self, stop_thread, q=self._watch_q)
+        self._finalizer = weakref.finalize(self, stop_thread, q=self._watch_q)
         self._finalizer.atexit = False
 
     def _on_exit(self, exitcode):
@@ -332,7 +330,7 @@ def _cleanup_dangling():
     for proc in list(_dangling):
         if proc.is_alive():
             try:
-                logger.warning("reaping stray process %s" % (proc,))
+                logger.info("reaping stray process %s" % (proc,))
                 proc.terminate()
             except OSError:
                 pass
