@@ -1,12 +1,12 @@
 from collections import defaultdict, deque
 import datetime
 import logging
+import threading
 import weakref
 
 import tornado.locks
 from tornado import gen
 
-from .compatibility import finalize, get_thread_identity
 from .core import CommClosedError
 from .utils import sync
 from .protocol.serialize import to_serialize
@@ -306,12 +306,11 @@ class Pub(object):
         if self.worker:
             pubsub = self.worker.extensions["pubsub"]
             self.loop.add_callback(pubsub.publishers[name].add, self)
-            finalize(self, pubsub.trigger_cleanup)
+            weakref.finalize(self, pubsub.trigger_cleanup)
 
-    @gen.coroutine
-    def _start(self):
+    async def _start(self):
         if self.worker:
-            result = yield self.scheduler.pubsub_add_publisher(
+            result = await self.scheduler.pubsub_add_publisher(
                 name=self.name, worker=self.worker.address
             )
             pubsub = self.worker.extensions["pubsub"]
@@ -386,10 +385,9 @@ class Sub(object):
         else:
             raise Exception()
 
-        finalize(self, pubsub.trigger_cleanup)
+        weakref.finalize(self, pubsub.trigger_cleanup)
 
-    @gen.coroutine
-    def _get(self, timeout=None):
+    async def _get(self, timeout=None):
         if timeout is not None:
             timeout = datetime.timedelta(seconds=timeout)
         start = datetime.datetime.now()
@@ -400,9 +398,9 @@ class Sub(object):
                     raise gen.TimeoutError()
             else:
                 timeout2 = None
-            yield self.condition.wait(timeout=timeout2)
+            await self.condition.wait(timeout=timeout2)
 
-        raise gen.Return(self.buffer.popleft())
+        return self.buffer.popleft()
 
     __anext__ = _get
 
@@ -410,7 +408,7 @@ class Sub(object):
         """ Get a single message """
         if self.client:
             return self.client.sync(self._get, timeout=timeout)
-        elif self.worker.thread_id == get_thread_identity():
+        elif self.worker.thread_id == threading.get_ident():
             return self._get()
         else:
             if self.buffer:  # fastpath
