@@ -1,5 +1,3 @@
-from __future__ import print_function, division, absolute_import
-
 from concurrent.futures import CancelledError
 import os
 import random
@@ -39,8 +37,7 @@ def test_submit_after_failed_worker_sync(loop):
 
 @gen_cluster(client=True, timeout=60, active_rpc_timeout=10)
 def test_submit_after_failed_worker_async(c, s, a, b):
-    n = Nanny(s.address, nthreads=2, loop=s.loop)
-    n.start(0)
+    n = yield Nanny(s.address, nthreads=2, loop=s.loop)
     while len(s.workers) < 3:
         yield gen.sleep(0.1)
 
@@ -128,7 +125,7 @@ def test_failed_worker_without_warning(c, s, a, b):
     assert all(len(keys) > 0 for keys in s.has_what.values())
     nthreads2 = dict(s.nthreads)
 
-    yield c._restart()
+    yield c.restart()
 
     L = c.map(inc, range(10))
     yield wait(L)
@@ -148,7 +145,7 @@ def test_restart(c, s, a, b):
 
     assert set(s.who_has) == {x.key, y.key}
 
-    f = yield c._restart()
+    f = yield c.restart()
     assert f is c
 
     assert len(s.workers) == 2
@@ -171,7 +168,7 @@ def test_restart_cleared(c, s, a, b):
     f = c.compute(x)
     yield wait([f])
 
-    yield c._restart()
+    yield c.restart()
 
     for coll in [s.tasks, s.unrunnable]:
         assert not coll
@@ -212,7 +209,7 @@ def test_restart_fast(c, s, a, b):
     L = c.map(sleep, range(10))
 
     start = time()
-    yield c._restart()
+    yield c.restart()
     assert time() - start < 10
     assert len(s.nthreads) == 2
 
@@ -255,7 +252,7 @@ def test_fast_kill(c, s, a, b):
     L = c.map(sleep, range(10))
 
     start = time()
-    yield c._restart()
+    yield c.restart()
     assert time() - start < 10
 
     assert all(x.status == "cancelled" for x in L)
@@ -267,23 +264,26 @@ def test_fast_kill(c, s, a, b):
 
 @gen_cluster(Worker=Nanny, timeout=60)
 def test_multiple_clients_restart(s, a, b):
-    e1 = yield Client(s.address, asynchronous=True)
-    e2 = yield Client(s.address, asynchronous=True)
+    c1 = yield Client(s.address, asynchronous=True)
+    c2 = yield Client(s.address, asynchronous=True)
 
-    x = e1.submit(inc, 1)
-    y = e2.submit(inc, 2)
+    x = c1.submit(inc, 1)
+    y = c2.submit(inc, 2)
     xx = yield x
     yy = yield y
     assert xx == 2
     assert yy == 3
 
-    yield e1._restart()
+    yield c1.restart()
 
     assert x.cancelled()
-    assert y.cancelled()
+    start = time()
+    while not y.cancelled():
+        yield gen.sleep(0.01)
+        assert time() < start + 5
 
-    yield e1._close(fast=True)
-    yield e2._close(fast=True)
+    yield c1.close()
+    yield c2.close()
 
 
 @gen_cluster(Worker=Nanny, timeout=60)
@@ -302,7 +302,7 @@ def test_restart_scheduler(s, a, b):
 @gen_cluster(Worker=Nanny, client=True, timeout=60)
 def test_forgotten_futures_dont_clean_up_new_futures(c, s, a, b):
     x = c.submit(inc, 1)
-    yield c._restart()
+    yield c.restart()
     y = c.submit(inc, 1)
     del x
     import gc
@@ -315,8 +315,7 @@ def test_forgotten_futures_dont_clean_up_new_futures(c, s, a, b):
 @gen_cluster(client=True, timeout=60, active_rpc_timeout=10)
 def test_broken_worker_during_computation(c, s, a, b):
     s.allowed_failures = 100
-    n = Nanny(s.address, nthreads=2, loop=s.loop)
-    n.start(0)
+    n = yield Nanny(s.address, nthreads=2, loop=s.loop)
 
     start = time()
     while len(s.nthreads) < 3:
@@ -365,7 +364,7 @@ def test_restart_during_computation(c, s, a, b):
 
     yield gen.sleep(0.5)
     assert s.rprocessing
-    yield c._restart()
+    yield c.restart()
     assert not s.rprocessing
 
     assert len(s.nthreads) == 2
@@ -374,8 +373,7 @@ def test_restart_during_computation(c, s, a, b):
 
 @gen_cluster(client=True, timeout=60)
 def test_worker_who_has_clears_after_failed_connection(c, s, a, b):
-    n = Nanny(s.address, nthreads=2, loop=s.loop)
-    n.start(0)
+    n = yield Nanny(s.address, nthreads=2, loop=s.loop)
 
     start = time()
     while len(s.nthreads) < 3:
